from django.urls import path

from buildblock.apps.administrator import views

app_name = "administrator"

urlpatterns = [
    path("",
         view=views.AdministratorTemplateView.as_view(template_name="administrator/index.html"),
         name="administrator_menu"),
    # User
    path('user/create/',
         view=views.InvitedUserCreateView.as_view(),
         name='user-create'),
    path('user/update/<int:pk>/',
         view=views.UserUpdateView.as_view(),
         name='user-update'),
    path('user/delete/<int:pk>/',
         view=views.UserDeleteView.as_view(),
         name='user-delete'),
    path('user/list/',
         view=views.UserListView.as_view(),
         name='user-list'),
    # Send Email to users
    path("email/",
         view=views.EmailTargetListView.as_view(template_name="administrator/email_target.html"),
         name="email"),
    path("email/message/",
         view=views.EmailWriteView.as_view(),
         name="email-message"),
    path("email/send/",
         view=views.administrator_send_message,
         name="email-message-send"),
    # Landing
    path("company-info/list/",
         view=views.LandingInfoListView.as_view(),
         name="company-info-list"),
    path("company-info/create/",
         view=views.LandingInfoCreateView.as_view(),
         name="company-info-create"),
    path("company-info/update/<int:pk>/",
         view=views.LandingInfoUpdateView.as_view(),
         name="company-info-update"),
    path("company-info/delete/<int:pk>/",
         view=views.LandingInfoDeleteView.as_view(),
         name="company-info-delete"),
    path("landing-document/create/",
         view=views.LandingDocumentCreateView.as_view(),
         name="landing-document-create"),
    path("landing-document/update/<int:pk>/",
         view=views.LandingDocumentUpdateView.as_view(),
         name="landing-document-update"),
    path("landing-document/delete/<int:pk>/",
         view=views.LandingDocumentDeleteView.as_view(),
         name="landing-document-delete"),
    path("history/list/",
         view=views.HistoryListView.as_view(),
         name="history-list"),
    path('history/create/',
         view=views.HistoryCreateView.as_view(),
         name='history-create'),
    path('history/update/<int:pk>/',
         view=views.HistoryUpdateView.as_view(),
         name='history-update'),
    path('history/delete/<int:pk>/',
         view=views.HistoryDeleteView.as_view(),
         name='history-delete'),
    path("team/list/",
         view=views.TeamListView.as_view(),
         name="team-list"),
    path('team/create/',
         view=views.TeamCreateView.as_view(),
         name='team-create'),
    path('team/update/<int:pk>/',
         view=views.TeamUpdateView.as_view(),
         name='team-update'),
    path('team/delete/<int:pk>/',
         view=views.TeamDeleteView.as_view(),
         name='team-delete'),
    path("case-study/list/",
         view=views.CaseStudyListView.as_view(),
         name="case-study-list"),
    path('case-study/create/view',
         view=views.CaseStudyCreateView.as_view(),
         name='case-study-create-view'),
    path('case-study/update/view/<int:pk>/',
         view=views.CaseStudyUpdateView.as_view(),
         name='case-study-update-view'),
    path('case-study/delete/<int:pk>/',
         view=views.CaseStudyDeleteView.as_view(),
         name='case-study-delete'),
    path('case-study/video/create/',
         view=views.create_case_study_video_ajax,
         name='case-study-video-create'),
    path('case-study/photo/create/',
         view=views.create_case_study_photo_ajax,
         name='case-study-photo-create'),
    path('case-study/media/delete/',
         view=views.delete_case_study_media_ajax,
         name='case-study-media-delete'),
    path("news/list/",
         view=views.NewsListView.as_view(),
         name="news-list"),
    path('news/create/',
         view=views.NewsCreateView.as_view(),
         name='news-create'),
    path('news/update/<int:pk>/',
         view=views.NewsUpdateView.as_view(),
         name='news-update'),
    path('news/delete/<int:pk>/',
         view=views.NewsDeleteView.as_view(),
         name='news-delete'),
    path("landing-video/list/",
         view=views.LandingVideoListView.as_view(),
         name="landing-video-list"),
    path("landing-video/create/",
         view=views.LandingVideoCreateView.as_view(),
         name="landing-video-create"),
    path("landing-video/update/<int:pk>/",
         view=views.LandingVideoUpdateView.as_view(),
         name="landing-video-update"),
    path("landing-video/delete/<int:pk>/",
         view=views.LandingVideoDeleteView.as_view(),
         name="landing-video-delete"),
    path("landing-asset/list/",
         view=views.LandingAssetListView.as_view(),
         name="landing-asset-list"),
    path("landing-carousel/create/",
         view=views.LandingCarouselCreateView.as_view(),
         name="landing-carousel-create"),
    path("landing-carousel/update/<int:pk>/",
         view=views.LandingCarouselUpdateView.as_view(),
         name="landing-carousel-update"),
    path("landing-carousel/delete/<int:pk>/",
         view=views.LandingCarouselDeleteView.as_view(),
         name="landing-carousel-delete"),
    path("landing-popup/create/",
         view=views.LandingCarouselCreateView.as_view(),
         name="landing-popup-create"),
    path("landing-popup/update/<int:pk>/",
         view=views.LandingCarouselUpdateView.as_view(),
         name="landing-popup-update"),
    path("landing-popup/delete/<int:pk>/",
         view=views.LandingCarouselDeleteView.as_view(),
         name="landing-popup-delete"),
    path("landing-thinbanner/create/",
         view=views.LandingCarouselCreateView.as_view(),
         name="landing-thinbanner-create"),
    path("landing-thinbanner/update/<int:pk>/",
         view=views.LandingCarouselUpdateView.as_view(),
         name="landing-thinbanner-update"),
    path("landing-thinbanner/delete/<int:pk>/",
         view=views.LandingCarouselDeleteView.as_view(),
         name="landing-thinbanner-delete"),
    path("faq/list/",
         view=views.FaqListView.as_view(),
         name="faq-list"),
    path('faq/create/',
         view=views.FaqCreateView.as_view(),
         name='faq-create'),
    path('faq/update/<int:pk>/',
         view=views.FaqUpdateView.as_view(),
         name='faq-update'),
    path('faq/delete/<int:pk>/',
         view=views.FaqDeleteView.as_view(),
         name='faq-delete'),
    # Product
    path("product/list/",
         view=views.AdministratorProductListView.as_view(),
         name="product-list"),
    path("product/detail/<int:pk>/",
         view=views.AdministratorProductDetailView.as_view(),
         name="product-detail"),
    path("product/create/",
         view=views.AdministratorProductCreateView.as_view(),
         name="product-create"),
    path("product/update/<int:pk>/",
         view=views.AdministratorProductUpdateView.as_view(),
         name="product-update"),
    path("product/delete/<int:pk>/",
         view=views.AdministratorProductDeleteView.as_view(),
         name="product-delete"),
    # Lease
    path("lease/list/",
         view=views.LeaseListView.as_view(),
         name="lease"),
    path('lease/detail/<int:pk>/',
         view=views.LeaseDetailView.as_view(),
         name='lease-detail'),
    path('lease/delete/<int:pk>/',
         view=views.LeaseDeleteView.as_view(),
         name='lease-delete'),
    path('lease/update/<int:pk>/',
         view=views.LeaseUpdateView.as_view(),
         name='lease-update'),
    path('lease/create/',
         view=views.LeaseCreateView.as_view(),
         name='lease-create'),
    # Payment
    path("payment/list/",
         view=views.PaymentListView.as_view(),
         name="payment"),
    path('payment/detail/<int:pk>/',
         view=views.PaymentDetailView.as_view(),
         name='payment-detail'),
    path('payment/delete/<int:pk>/',
         view=views.PaymentDeleteView.as_view(),
         name='payment-delete'),
    path('payment/update/<int:pk>/',
         view=views.PaymentUpdateView.as_view(),
         name='payment-update'),
    path('payment/create/',
         view=views.PaymentCreateView.as_view(),
         name='payment-create'),
    path('payment/charge/',
         view=views.charge_payment,
         name='payment-charge'),
    # Payment
    path('payment_transfer/list/',
         view=views.PaymentTransferListView.as_view(),
         name='payment-transfer'),
    path('payment_transfer/detail/<int:pk>/',
         view=views.PaymentTransferDetailView.as_view(),
         name='payment-transfer-detail'),
    path('payment_transfer/delete/<int:pk>/',
         view=views.PaymentTransferCreateView.as_view(),
         name='payment-transfer-delete'),
    path('payment_transfer/update/<int:pk>/',
         view=views.PaymentTransferUpdateView.as_view(),
         name='payment-transfer-update'),
    path('payment_transfer/create/',
         view=views.PaymentTransferDeleteView.as_view(),
         name='payment-transfer-create'),
    # Investment
    path("investment/create/<int:investment_product_id>/<int:user_id>/",
         view=views.InvestmentCreateView.as_view(),
         name="investment-create"),
    path("investment/update/<int:pk>/",
         view=views.InvestmentUpdateView.as_view(),
         name="investment-update"),
    path("investment/delete/<int:pk>/",
         view=views.InvestmentDeleteView.as_view(),
         name="investment-delete"),
    path("investment/detail/<int:pk>/",
         view=views.InvestmentDetailView.as_view(),
         name="investment-detail"),
    path("investment/step/create/<int:investment_id>/<str:stage_id>/",
         view=views.InvestmentStepCreateView.as_view(),
         name="investment-step-create"),
    path("investment/step/update/<int:pk>/",
         view=views.InvestmentStepUpdateView.as_view(),
         name="investment-step-update"),
    path("investment/step/delete/<int:pk>/",
         view=views.InvestmentStepDeleteView.as_view(),
         name="investment-step-delete"),
    path("investment/step/email/<int:pk>/",
         view=views.InvestmentStepEmailView.as_view(),
         name="investment-step-email"),
    path("investment/step/email/send/",
         view=views.send_investment_step_email,
         name="investment-step-email-send"),
    # Investment-Product
    path("investment/product/list/",
         view=views.InvestmentProductListView.as_view(),
         name="investment-product-list"),
    path("investment/product/create/",
         view=views.InvestmentProductCreateView.as_view(),
         name="investment-product-create"),
    path("investment/product/detail/<int:pk>/",
         view=views.InvestmentProductDetailView.as_view(),
         name="investment-product-detail"),
    path("investment/product/delete/<int:pk>/",
         view=views.InvestmentProductDeleteView.as_view(),
         name="investment-product-delete"),
    path("investment/product/update/<int:pk>/",
         view=views.InvestmentProductUpdateView.as_view(),
         name="investment-product-update"),
    path("investment/product/<int:investment_product_id>/add/product/<int:product_id>/",
         view=views.add_product_to_investment_product,
         name="investment-product-add-product"),
    path("investment/product/<int:investment_product_id>/delete/product/<int:product_id>/",
         view=views.delete_product_to_investment_product,
         name="investment-product-delete-product"),
    # Investment-Investor
    path("investor/list/",
         view=views.InvestorListView.as_view(),
         name="investor-list"),
    path("investor/detail/<int:pk>/",
         view=views.InvestorDetailView.as_view(),
         name="investor-detail"),
    # Investment-Contract
    path("envelope_doc_download/<str:envelope_id>/",
         view=views.envelope_document_download,
         name="esignature-document-download"),
    path("create_envelope_recipient_view/<str:envelope_id>/",
         view=views.create_envelope_recipient_view,
         name="esignature-envelope-recipient-view"),
    path("investment/<int:investment_id>/contract/template/select/",
         view=views.InvestmentContractTemplateSelectView.as_view(),
         name="investment-contract-template-select"),
    path("investment/<int:investment_id>/contract/create/<str:template_id>/",
         view=views.InvestmentContractCreateView.as_view(),
         name="investment-contract-create"),
    path("investment/contract/delete/<int:pk>/",
         view=views.InvestmentContractDeleteView.as_view(),
         name="investment-contract-delete"),
    path("investment/contract/update/<int:pk>/",
         view=views.InvestmentContractUpdateView.as_view(),
         name="investment-contract-update"),
    # Contract Template
    path("contract/template/list/",
         view=views.ContractTemplateListView.as_view(),
         name="contract-template-list"),
    path("contract/template/create/",
         view=views.ContractTemplateCreateView.as_view(),
         name="contract-template-create"),
    path("contract/template/update/<int:pk>/",
         view=views.ContractTemplateUpdateView.as_view(),
         name="contract-template-update"),
    path("contract/template/delete/<int:pk>/",
         view=views.ContractTemplateDeleteView.as_view(),
         name="contract-template-delete"),
    # Property
    path("property/list/sale/<str:info_origin>/",
         view=views.PropertySaleListView.as_view(),
         name="property-sale-list"),
    path("property/list/sold/<str:info_origin>/",
         view=views.PropertySoldListView.as_view(),
         name="property-sold-list"),
    path("property/detail/<str:info_origin>/<str:property_id>/",
         view=views.PropertyDetailView.as_view(),
         name="property-detail"),
    path("property/filter/list/<str:info_origin>/",
         view=views.PropertyFilterListView.as_view(),
         name="property-filter-list"),
    path("property/filter/create/<str:info_origin>/",
         view=views.PropertyFilterCreateView.as_view(),
         name="property-filter-create"),
    path("property/filter/update/<str:info_origin>/<str:filter_id>/",
         view=views.PropertyFilterUpdateView.as_view(),
         name="property-filter-update"),
    path("property/filter/delete/<str:info_origin>/<str:filter_id>/",
         view=views.PropertyFilterDeleteView.as_view(),
         name="property-filter-delete"),
]
