from django.urls import path

from buildblock.apps.construction import views

app_name = "construction"

urlpatterns = [
    path("",
         view=views.ConstructionListView.as_view(),
         name="home"),
    # Construction
    path("create/",
         view=views.ConstructionCreateView.as_view(),
         name="create"),
    path("delete/<int:pk>/",
         view=views.ConstructionDeleteView.as_view(),
         name="delete"),
    path("update/<int:pk>/",
         view=views.ConstructionUpdateView.as_view(),
         name="update"),
    path("info/<int:construction_id>/",
         view=views.ConstructionTemplateView.as_view(),
         name="info"),
    # Product
    path("<int:construction_id>/zone/",
         view=views.ProductZoneView.as_view(),
         name="zone-list"),
    path("zone/create/",
         view=views.add_zone,
         name="zone-create"),
    path("zone/update/",
         view=views.edit_zone,
         name="zone-update"),
    path("zone/delete/",
         view=views.delete_zone,
         name="zone-delete"),
    # Work
    path("<int:construction_id>/work/list/",
         view=views.WorkListView.as_view(),
         name="work-list"),
    path("<int:construction_id>/work/info/<int:pk>/",
         view=views.WorkDetailView.as_view(),
         name="work-detail"),
    path("work/create/",
         view=views.add_work,
         name="work-create"),
    path("work/delete/",
         view=views.delete_work,
         name="work-delete"),
    path("work/update/",
         view=views.edit_work,
         name="work-update"),
    path("daily-report/add-work-date/",
         view=views.add_work_date,
         name="add-work-date"),
    path("daily-report/delete-work-date/",
         view=views.delete_work_date,
         name="delete-work-date"),
    # Picture
    path("<int:construction_id>/picture/list/",
         view=views.PictureListView.as_view(),
         name="picture-list"),
    path("picture/create/",
         view=views.add_picture,
         name="picture-create"),
    path("picture/delete/",
         view=views.delete_picture,
         name="picture-delete"),
    path("picture/update/",
         view=views.edit_picture,
         name="picture-update"),
    # Worker
    path("<int:construction_id>/worker/list/",
         view=views.WorkerListView.as_view(),
         name="worker-list"),
    path("worker/create/",
         view=views.add_worker,
         name="worker-create"),
    path("worker/delete/",
         view=views.delete_worker,
         name="worker-delete"),
    path("worker/update/",
         view=views.edit_worker,
         name="worker-update"),
    # Expense
    path("<int:construction_id>/expense/list/",
         view=views.ExpenseListView.as_view(),
         name="expense-list"),
    path("<int:construction_id>/personnel-expense/list/",
         view=views.PersonnelExpenseListView.as_view(),
         name="personnel-expense-list"),
    path("<int:construction_id>/outsourcing-expense/list/",
         view=views.OutsourcingExpenseListView.as_view(),
         name="outsourcing-expense-list"),
    path("expense/create/",
         view=views.add_expense,
         name="expense-create"),
    path("personnel-expense/create/",
         view=views.add_personnel_expense,
         name="personnel-expense-create"),
    path("outsourcing-contract/create/",
         view=views.add_outsourcing_contract,
         name="outsourcing-contract-create"),
    path("outsourcing-expense/create/",
         view=views.add_outsourcing_expense,
         name="outsourcing-expense-create"),
    path("expense/update/",
         view=views.edit_expense,
         name="expense-update"),
    path("personnel-expense/update/",
         view=views.edit_personnel_expense,
         name="personnel-expense-update"),
    path("outsourcing-contract/update/",
         view=views.edit_outsourcing_contract,
         name="outsourcing-contract-update"),
    path("outsourcing-expense/update/",
         view=views.edit_outsourcing_expense,
         name="outsourcing-expense-update"),
    path("personnel-expense/update/payment-date/",
         view=views.edit_payment_date,
         name="edit-payment-date"),
    path("expense/delete/",
         view=views.delete_expense,
         name="expense-delete"),
    path("outsourcing-contract/delete/",
         view=views.delete_outsourcing_contract,
         name="outsourcing-contract-delete"),
    path("outsourcing-expense/delete/",
         view=views.delete_outsourcing_expense,
         name="outsourcing-expense-delete"),
    path("<int:construction_id>/multiple-personnel-expense/form/",
         view=views.MultiPersonnelExpenseFormView.as_view(),
         name="multiple-personnel-expense-form"),
    path("multiple-personnel-expense/save/",
         view=views.save_multiple_personnel_expenses,
         name="multiple-personnel-expense-save"),
    path("<int:construction_id>/multiple-expense/form/",
         view=views.MultiExpenseFormView.as_view(),
         name="multiple-expense-form"),
    path("multiple-expense/save/",
         view=views.save_multiple_expenses,
         name="multiple-expense-save"),
    # Report
    path("<int:construction_id>/daily-report/list/",
         view=views.DailyReportListView.as_view(),
         name="daily-report-list"),
    path("<int:construction_id>/daily-report/create/<str:report_date>/",
         view=views.DailyReportCreateView.as_view(),
         name="daily-report-create"),
    path("<int:construction_id>/daily-report/update/<int:pk>/<str:report_date>/",
         view=views.DailyReportUpdateView.as_view(),
         name="daily-report-update"),
    path("<int:construction_id>/weekly-report/list/",
         view=views.WeeklyReportListView.as_view(),
         name="weekly-report-list"),
    path("weekly-report/create/",
         view=views.add_weekly_report,
         name="weekly-report-create"),
    path("<int:construction_id>/weekly-report/update/<int:pk>/",
         view=views.WeeklyReportUpdateView.as_view(),
         name="weekly-report-update"),
]
