from django.urls import path

from buildblock.apps.core.constants import MANAGEMENT_APP_NAME
from buildblock.apps.management import views
from buildblock.apps.users.views import active_role_change

app_name = MANAGEMENT_APP_NAME
urlpatterns = [
    # Main Page
    path("",
         view=views.ManagementMainPageView.as_view(),
         name="home"),

    # Account
    path("signup/",
         view=views.ManagementRoleSignupSelectView.as_view(),
         name="signup-choice"),
    path("signup/<str:application_role>/",
         view=views.ManagementRoleSignupView.as_view(),
         name="signup-role"),
    path("select/",
         view=views.ManagementRoleSelectView.as_view(),
         name="select-role"),
    path("role_change/<str:user_role>/",
         view=active_role_change,
         name="change-role"),
    path("profile_update/",
         view=views.ManagementRoleUpdateView.as_view(),
         name="profile-update"),
    path("bank_account/registration",
         view=views.ManagementBankAccountRegistrationView.as_view(),
         name="bank-account-registration"),
    path("bank_account/registration/submit",
         view=views.bank_account_register,
         name="bank-account-registration-submit"),
    path("bank_account/verification/submit",
         view=views.bank_account_verify,
         name="bank-account-verification-submit"),
    path("bank_account/unlink/submit",
         view=views.bank_account_unlink,
         name="bank-account-unlink-submit"),

    # For both
    path("profile",
         view=views.ManagementProfileView.as_view(),
         name="profile"),
    path("maintenance/",
         view=views.ManagementMaintenanceListView.as_view(),
         name="maintenance"),
    path("maintenance/write/",
         view=views.ManagementMaintenanceCreateView.as_view(),
         name="maintenance-write"),
    path("maintenance/read/<int:pk>/",
         view=views.ManagementMaintenanceDetailView.as_view(),
         name="maintenance-read"),
    path("maintenance/edit/<int:pk>/",
         view=views.ManagementMaintenanceUpdateView.as_view(),
         name="maintenance-edit"),
    path("maintenance/status/change/",
         view=views.maintenance_status_change,
         name="maintenance-change-to-resolved"),
    path("maintenance/comment/add/",
         view=views.maintenance_comment_add,
         name="maintenance-comment-add"),
    path("maintenance/comment/delete/",
         view=views.maintenance_comment_delete,
         name="maintenance-comment-delete"),

    # For owner
    path("overview",
         view=views.ManagementOverviewView.as_view(),
         name="overview"),
    path("product/list",
         view=views.ManagementProductListView.as_view(),
         name="product-list"),
    path("product/create",
         view=views.ManagementProductCreateView.as_view(),
         name="product-create"),
    path("product/update/<int:pk>",
         view=views.ManagementProductUpdateView.as_view(),
         name="product-update"),
    path("product/info/<str:product_code>",
         view=views.ManagementProductInfoView.as_view(),
         name="product-info"),
    path("tenant/list",
         view=views.ManagementTenantListView.as_view(),
         name="tenant-list"),
    path("tenant/lease-create/<str:product_code>",
         view=views.ManagementLeaseCreateView.as_view(),
         name="lease-create"),
    path("tenant/lease-update/<int:pk>",
         view=views.ManagementLeaseUpdateView.as_view(),
         name="lease-update"),
    path("tenant/<int:pk>",
         view=views.ManagementTenantDetailView.as_view(),
         name="tenant-detail"),
    path("transaction",
         view=views.ManagementTransactionListView.as_view(),
         name="transaction"),
    path("transaction/read/<int:pk>",
         view=views.ManagementTransactionDetailView.as_view(),
         name="transaction-read"),
    path("transaction/update/<int:pk>",
         view=views.ManagementTransactionUpdateView.as_view(),
         name="transaction-update"),
    path("transaction/create/<int:lease_id>",
         view=views.ManagementTransactionCreateView.as_view(),
         name="transaction-create"),
    path("document/list",
         view=views.ManagementDocumentListView.as_view(),
         name="document-list"),
    path("document/create",
         view=views.ManagementDocumentCreateView.as_view(),
         name="document-create"),
    path("document/update/<int:pk>",
         view=views.ManagementDocumentUpdateView.as_view(),
         name="document-update"),
    path("document/download/<int:pk>",
         view=views.ManagementDocumentDownloadView.as_view(),
         name="document-download"),

    # For tenant
    path("house",
         view=views.ManagementHouseView.as_view(),
         name="house"),
    path("owner/list",
         view=views.ManagementOwnerListView.as_view(),
         name="owner-list"),
    path("owner/<int:pk>",
         view=views.ManagementOwnerDetailView.as_view(),
         name="owner-detail"),

    # For agent
    path("group_update/<int:pk>",
         view=views.ManagementGroupUpdateView.as_view(),
         name="group-update"),

    # Payment
    path("payment/status",
         view=views.PaymentStatusView.as_view(),
         name="payment-status"),
    path("payment/autopay/register",
         view=views.register_auto_payment,
         name="payment-autopay-register"),
    path("payment/autopay/unregister",
         view=views.unregister_auto_payment,
         name="payment-autopay-unregister")
]
